==> pot-3.5.0.src.tar.gz: pot-3.5/main.c <==
/*
pot est un programme servant  lister vos "pot" sur un rseau
Copyright (C) 2001 Fabien Carrion et Guillaume Pinot

Ce programme est libre, vous pouvez le redistribuer et/ou le modifier selon les
termes de la Licence Publique Gnrale GNU publie par la Free Software
Foundation (version 2).

Ce programme est distribu car potentiellement utile, mais SANS AUCUNE
GARANTIE, ni explicite ni implicite, y compris les garanties de
commercialisation ou d'adaptation dans un but
spcifique. Reportez-vous  la Licence Publique Gnrale GNU pour plus
de dtails.

Vous devez avoir reu une copie de la Licence Publique Gnrale GNU en mme
temps que ce programme ; si ce n'est pas le cas, crivez  la Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, tats-Unis.

fcarrion@etu.utc.fr
pinotgui@etu.utc.fr
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <getopt.h>

#include "console/console.h"
#include "commun.h"
#include "main.h"

#ifdef GTKUSE
#include "gtk/potgtk.h"
#endif

int options;


/* 
   verifie que le fichier passe en argument existe et est accessible
   Renvoit 0 en cas de probleme
*/
int check_fichierpots(char *chemin)
{
  int file;

  /* tentative d'ouverture du fichier */
  file = open(chemin, O_RDONLY);

  if(file == -1)
    {
      printf("Erreur lors de l'ouverture du fichier '%s'\n", chemin);
      return 0;
    }

  close(file);

  return 1;
}

void add_showone(char *login)
{
  pots_showone = ajout_liste_pot(login, pots_showone);
}

void usage (char *nom){
  /* Note to Pinotgui : 
   * ISO C89 compilers are not required to support strings greater than `509'
   * so you have to split the initial printf into three ones 
   * if not, the string is 945 !!! 
   * -->Flux<-- :-) */

  printf("Pot %s par Fabien Carrion et Guillaume Pinot\n"
	 "G.U.I. par Tahorg\n"
	 "Participation de Bertrand Bonnafous\n"
	 "Ajout de la gestion des skins par Flux (Julien Delacroix)\n"
	 "Site: http://wwwetu.utc.fr/~pinotgui/\n\n"
	 "utilisation : %s [-acghilqo] [ -f fichier ] [login1 [login2...]\n"
	 "\t\t[ -r login ] [ -p login ] ;\n"
	 "\tlogin1 login2\trajoute des logins dans votre liste de \"pot\" ;\n",
	 VERSION,nom);
  printf("\t-a\t\taffiche la liste des personnes connectes\n"

#ifdef GTKUSE
	 "\t-g\t\tlance potgtk, la version Graphique ;\n"
#endif	     
	 "\t-s NOM\t\tutilise la skin 'NOM.xml', les skins sont dans\n"
	 "\t\t\t~/.pot/skin ;\n"
	 "\t-h\t\taffiche ce message d'aide ;\n"
	 "\t-l\t\taffiche votre liste de \"pots\" ;\n"
	 "\t-p login\tlance la recherche sur un \"pot\" particulier ;\n"
	 "\t-q\t\tmasquer la barre de titre ;\n"
	 "\t-r\t\tenlve un login de votre liste de \"pot\" ;\n");
  printf("\t-u\t\taffiche seulement les personnes connectes depuis un\n"
	 "\t\t\tterminal ;\n"
#ifdef SAMBA
	 "\t-w\t\taffiche seulement les personnes utilisant samba ;\n"
#endif
	 "\n"
	 "Pot Perso? Voir %s et %s\n",POTSALDEFAULT, SKINDIR);
}

/* fonction de traitement des options 
   /!\ on suppose que le fichier .pot.pot existe /!\

   retourne :

   -1 : si on doit arreter l'execution
   0 : sinon
*/
int reconnaissance_options(int argc, char **argv, char **chemin,  char *skin_file)
{
  char c;
  FILE *pot;
  int i;

  /* initialisation de la variable options */
  options = 0x0 | OPTION_COULEUR;
  opterr = 0;

  /* Les arguments */
  while ( ( c = getopt(argc,argv,"hlgcoiduwaqr:s:p:f:") ) != -1 ) 
    {
	 switch ( c )
	   {
		/* aide */
	   case 'h' :
	     usage(argv[0]);
	     return -1;
	     /* lance la version sans couleur */
	     
	   case 'c' :
	     options &= ~OPTION_COULEUR;
	     break;
		
#ifdef GTKUSE
		/* Lance potgtk (en graphique) */
	   case 'g' :
	     options |= OPTION_GTK;
	     break;
#endif
	   case 'q':
	     options |= OPTION_QUIET;
	     break;
		
		/* visualisation des logins enregistrs pour localhost */
	   case 'l' :
	     options |= OPTION_LISTEPOTS;
	     break;
	
	/* visualisation des logins enregistrs pour linux
	   case 't' :
	   strcat(chemin,".linux");
	   view(chemin);
	   return 0; */
	
           /* suppression d'un login pour localhost */
	   case 'r' :
	     printf("Suppression d'un pot : %s\n", optarg);
	     suppr(*chemin,optarg);
	     return -1;


           /* recuperation de la skin */
           case 's' :
	     strncpy(skin_file,optarg,15);
             break;

	   case 'd':
	     options |= OPTION_HIDEDOUBLE;
	     break;

	   case 'i':
	     options |= OPTION_HIDEIDLE;
	     break;

	   case 'o':
	     options |= OPTION_SHOWCOMP;
	     break;

	   case 'w':
#ifdef SAMBA
	     options |= OPTION_ONLYSAMBA;
#else
	     printf("Le support de Samba n'est pas integr, ");
	     printf("l'option -w est ignor\n");
#endif
	     break;
	     
	   case 'u':
	     options |= OPTION_ONLYTERM;
	     break;

	   case 'a':
	     options |= OPTION_SHOWALL;
	     break;

	   case 'p':
	     options |= OPTION_SHOWONE;
	     add_showone(optarg);
	     break;

	   case 'f':
	     if(strcmp(optarg,"-"))
	       {
		 if(!check_fichierpots(optarg))
		   break;
		 free(*chemin);
		 if ( ( *chemin = (char *) malloc(sizeof(char)*(strlen(optarg)))) == NULL )
		   {
		     fprintf( stderr , "Allocation de memoire impossible" );
		     return -1;
		   }
		 strcpy(*chemin,optarg);
	       }
	     else
	       {
		 *chemin = NULL;
	       }
	     options |= OPTION_POTFILE;
	     break;

		/* arguments invalide */
	   default  :
		printf("Argument invalide, tapez %s -h pour avoir de l'aide\n",argv[0]);
		return -1;
	   }
    }

  /* On n'a pas trait tous les arguments de la ligne de commande,
     je suppose donc que c'est un nouveau pot a rajouter
  */

  if(argv[optind] != NULL)
    {
      i = optind;

      pot = fopen(*chemin, "a");
      erreur(pot);

	 if(!pot)
	   return 0;

	 while(argv[i] != NULL)
	   {
		if (verif_login(argv[i],1,*chemin,NULL) == 0)
		  {
		    fprintf( pot , "%s\n" , argv[i] );
		    printf("%s a ete ajoute.\n",argv[i]);
		  }
		else
		  printf("%s est un login inexistant ou deja present dans votre liste.\n",argv[i]);
		i++;
	   }

	 fclose(pot);
    }

  return 1;
}

/* fonction principale */
int main(int argc , char *argv[] /*, char *envp[]*/)
{
  /* initialisation des variables */
  char skin_file[20]="";
  char *chemin;
  FILE *pot;

  /* recueil du chemin de pot.pot et de pot.pot.linux */
  if ( ( chemin = (char *) malloc(sizeof(char)*(strlen(getenv("HOME")) + 20)) ) == NULL )
    {
      fprintf( stderr , "Allocation de memoire impossible" );
      return -1;
    }

  strcpy ( chemin , getenv("HOME") );
  strcat ( chemin , "/.pot.pot" );

  if(reconnaissance_options(argc,argv,&chemin, skin_file) == -1)
    {
	 exit(EXIT_FAILURE);
    }

  if ((chemin != NULL) && (pot = fopen(chemin, "r")) == NULL)
    {
      fprintf(stderr,"~/.pot.pot n'existe pas.\n"
	      "Pour plus d'informations tapez : pot -h\n");
	 exit(EXIT_FAILURE);
    }

  if(IS_OPTION_SET(OPTION_LISTEPOTS))
    {
	 view(chemin);
	 return(EXIT_SUCCESS);
    }

  if(IS_OPTION_SET(OPTION_GTK))
    potgtk(chemin , argc , argv);
  else
    console (chemin, skin_file);

  return 0;
}

==> pot-3.6.0.src.tar.gz: pot-3.6/main.c <==
/*
pot est un programme servant  lister vos "pot" sur un rseau
Copyright (C) 2001 Fabien Carrion et Guillaume Pinot

Ce programme est libre, vous pouvez le redistribuer et/ou le modifier selon les
termes de la Licence Publique Gnrale GNU publie par la Free Software
Foundation (version 2).

Ce programme est distribu car potentiellement utile, mais SANS AUCUNE
GARANTIE, ni explicite ni implicite, y compris les garanties de
commercialisation ou d'adaptation dans un but
spcifique. Reportez-vous  la Licence Publique Gnrale GNU pour plus
de dtails.

Vous devez avoir reu une copie de la Licence Publique Gnrale GNU en mme
temps que ce programme ; si ce n'est pas le cas, crivez  la Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, tats-Unis.

fcarrion@etu.utc.fr
pinotgui@etu.utc.fr
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <getopt.h>

#include "trace/trace.h"
#include "console/console.h"
#include "commun.h"
#include "main.h"

#ifdef GTKUSE
#include "gtk/potgtk.h"
#endif

int options;

char * traceLogin ;

/* 
   verifie que le fichier passe en argument existe et est accessible
   Renvoit 0 en cas de probleme
*/
int check_fichierpots(char *chemin)
{
  int file;

  /* tentative d'ouverture du fichier */
  file = open(chemin, O_RDONLY);

  if(file == -1)
    {
      printf("Erreur lors de l'ouverture du fichier '%s'\n", chemin);
      return 0;
    }

  close(file);

  return 1;
}

void add_showone(char *login)
{
  pots_showone = ajout_liste_pot(login, pots_showone);
}

void usage (char *nom){
  /* Note to Pinotgui : 
   * ISO C89 compilers are not required to support strings greater than `509'
   * so you have to split the initial printf into three ones 
   * if not, the string is 945 !!! 
   * -->Flux<-- :-) */
  /* Answer by Pinotgui : C99 rulez, and You can talk to me in french! ;-) */

  printf("Pot %s par Guillaume Pinot, Fabien Carrion, Tahorg, Bertrand Bonnafous et\n"
	 "Flux (Julien Delacroix) (ordre de contribution)\n"
	 "Site: http://wwwetu.utc.fr/~pinotgui/\n\n"
	 "utilisation : %s [-acdghlq] [-f fichier] [-p login] [-r login]\n"
	 "\t\t[-t login] [login1 [login2...]];\n"
	 "\tlogin1 login2\trajoute des logins dans votre liste de \"pot\" ;\n",
	 VERSION,nom);
  printf("\t-a\t\taffiche la liste des personnes connectes ;\n"
	 "\t-c\t\tsupprime la couleur (sans effet pour le moment) ;\n"
	 "\t-d\t\tsupprime les doublons ;\n"
	 "\t-f fichier\tutilise fichier comme liste de pot ;\n"

#ifdef GTKUSE
	 "\t-g\t\tlance potgtk, la version Graphique ;\n"
#endif	     
	 "\t-s NOM\t\tutilise la skin 'NOM.xml', les skins sont dans\n"
	 "\t\t\t~/.pot/skin ;\n"
	 "\t-h\t\taffiche ce message d'aide ;\n"
	 "\t-l\t\taffiche votre liste de \"pots\" ;\n"
	 "\t-p login\tlance la recherche sur un \"pot\" particulier ;\n"
	 "\t-q\t\tmasquer la barre de titre ;\n"
	 "\t-r login\tenlve un login de votre liste de \"pot\" ;\n"
	 "\t-t login\ttrace les connexions d'un \"pot\" particulier ;\n");
  printf("\t-u\t\taffiche seulement les personnes connectes depuis un\n"
	 "\t\t\tterminal ;\n"
#ifdef SAMBA
	 "\t-w\t\taffiche seulement les personnes utilisant samba ;\n"
#endif
	 "\n"
	 "Pot Perso? Voir %s et %s\n",POTSALDEFAULT, SKINDIR);
}

/* fonction de traitement des options 
   /!\ on suppose que le fichier .pot.pot existe /!\

   retourne :

   -1 : si on doit arreter l'execution
   0 : sinon
*/
int reconnaissance_options(int argc, char **argv, char **chemin,  char *skin_file)
{
  char c;
  FILE *pot;
  int i;

  /* initialisation de la variable options */
  options = 0x0 | OPTION_COULEUR;
  opterr = 0;

  /* Les arguments */
  while ( ( c = getopt(argc,argv,"hlgcduwaqr:s:p:f:t:") ) != -1 ) 
    {
	 switch ( c )
	   {
		/* aide */
	   case 'h' :
	     usage(argv[0]);
	     return -1;
	     /* lance la version sans couleur */
	     
	   case 'c' :
	     options &= ~OPTION_COULEUR;
	     break;
		
#ifdef GTKUSE
		/* Lance potgtk (en graphique) */
	   case 'g' :
	     options |= OPTION_GTK;
	     break;
#endif
	   case 'q':
	     options |= OPTION_QUIET;
	     break;
		
		/* visualisation des logins enregistrs pour localhost */
	   case 'l' :
	     options |= OPTION_LISTEPOTS;
	     break;
	
	/* visualisation des logins enregistrs pour linux
	   case 't' :
	   strcat(chemin,".linux");
	   view(chemin);
	   return 0; */
	
           /* suppression d'un login pour localhost */
	   case 'r' :
	     printf("Suppression d'un pot : %s\n", optarg);
	     suppr(*chemin,optarg);
	     return -1;


           /* recuperation de la skin */
           case 's' :
	     strncpy(skin_file,optarg,15);
             break;

	   case 'd':
	     options |= OPTION_HIDEDOUBLE;
	     break;

	   case 'w':
#ifdef SAMBA
	     options |= OPTION_ONLYSAMBA;
#else
	     printf("Le support de Samba n'est pas integr, ");
	     printf("l'option -w est ignor\n");
#endif
	     break;
	     
	   case 'u':
	     options |= OPTION_ONLYTERM;
	     break;

	   case 'a':
	     options |= OPTION_SHOWALL;
	     break;

	   case 'p':
	     options |= OPTION_SHOWONE;
	     add_showone(optarg);
	     break;

	   case 't':
	     options |= OPTION_TRACE;
	     traceLogin = optarg;
	     break;

	   case 'f':
	     if(strcmp(optarg,"-"))
	       {
		 if(!check_fichierpots(optarg))
		   break;
		 free(*chemin);
		 if ( ( *chemin = (char *) malloc(sizeof(char)*(strlen(optarg)))) == NULL )
		   {
		     fprintf( stderr , "Allocation de memoire impossible" );
		     return -1;
		   }
		 strcpy(*chemin,optarg);
	       }
	     else
	       {
		 *chemin = NULL;
	       }
	     options |= OPTION_POTFILE;
	     break;

		/* arguments invalide */
	   default  :
		printf("Argument invalide, tapez %s -h pour avoir de l'aide\n",argv[0]);
		return -1;
	   }
    }

  /* On n'a pas trait tous les arguments de la ligne de commande,
     je suppose donc que c'est un nouveau pot a rajouter
  */

  if(argv[optind] != NULL)
    {
      i = optind;

      pot = fopen(*chemin, "a");
      erreur(pot);

	 if(!pot)
	   return 0;

	 while(argv[i] != NULL)
	   {
		if (verif_login(argv[i],1,*chemin,NULL) == 0)
		  {
		    fprintf( pot , "%s\n" , argv[i] );
		    printf("%s a ete ajoute.\n",argv[i]);
		  }
		else
		  printf("%s est un login inexistant ou deja present dans votre liste.\n",argv[i]);
		i++;
	   }

	 fclose(pot);
    }

  return 1;
}

/* fonction principale */
int main(int argc , char *argv[] /*, char *envp[]*/)
{
  /* initialisation des variables */
  char skin_file[20]="";
  char *chemin;
  FILE *pot;

  /* recueil du chemin de pot.pot et de pot.pot.linux */
  if ( ( chemin = (char *) malloc(sizeof(char)*(strlen(getenv("HOME")) + 20)) ) == NULL )
    {
      fprintf( stderr , "Allocation de memoire impossible" );
      return -1;
    }

  strcpy ( chemin , getenv("HOME") );
  strcat ( chemin , "/.pot.pot" );

  if(reconnaissance_options(argc,argv,&chemin, skin_file) == -1)
    {
	 exit(EXIT_FAILURE);
    }

  if ((chemin != NULL) && (pot = fopen(chemin, "r")) == NULL)
    {
      fprintf(stderr,"~/.pot.pot n'existe pas.\n"
	      "Pour plus d'informations tapez : pot -h\n");
	 exit(EXIT_FAILURE);
    }

	if (IS_OPTION_SET (OPTION_TRACE))
	{
		if (trace (traceLogin))
		{
			printf ("ERREUR\n") ;
			free (chemin) ;
			return (EXIT_FAILURE) ;
		}
		free (chemin) ;
		return (EXIT_SUCCESS) ;
	}

  if(IS_OPTION_SET(OPTION_LISTEPOTS))
    {
	 view(chemin);
	 return(EXIT_SUCCESS);
    }

  if(IS_OPTION_SET(OPTION_GTK))
    potgtk(chemin , argc , argv);
  else
    console (chemin, skin_file);

  return 0;
}
